summaryrefslogtreecommitdiffstats
path: root/hugolib/content_map.go
diff options
context:
space:
mode:
authorPhil Davis <phil@jankaritech.com>2020-12-16 16:56:32 +0545
committerGitHub <noreply@github.com>2020-12-16 12:11:32 +0100
commit04b89857e104ac7dcbf9fc65d8d4f1a1178123e6 (patch)
tree585bf761f0a1cfc69dffcd8afd22e94ca9da7c07 /hugolib/content_map.go
parent21fa1e86f2aa929fb0983a0cc3dc4e271ea1cc54 (diff)
all: Fix minor typos
Diffstat (limited to 'hugolib/content_map.go')
-rw-r--r--hugolib/content_map.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/hugolib/content_map.go b/hugolib/content_map.go
index ca2aa3672..3f5ed65c3 100644
--- a/hugolib/content_map.go
+++ b/hugolib/content_map.go
@@ -58,8 +58,8 @@ const (
cmLeafSeparator = "__hl_"
)
-// Used to mark ambigous keys in reverse index lookups.
-var ambigousContentNode = &contentNode{}
+// Used to mark ambiguous keys in reverse index lookups.
+var ambiguousContentNode = &contentNode{}
func newContentMap(cfg contentMapConfig) *contentMap {
m := &contentMap{
@@ -86,8 +86,8 @@ func newContentMap(cfg contentMapConfig) *contentMap {
addToReverseMap := func(k string, n *contentNode, m map[interface{}]*contentNode) {
k = strings.ToLower(k)
existing, found := m[k]
- if found && existing != ambigousContentNode {
- m[k] = ambigousContentNode
+ if found && existing != ambiguousContentNode {
+ m[k] = ambiguousContentNode
} else if !found {
m[k] = n
}